# QtFrameless

## Version 0.1.4

-   Fixed bug in with maximize window titlebar button.

## Version 0.1.3

-   Fixed bug in pypi and github installations

## Version 0.1.2

-   Minor improvements to title bar and tile bar buttons.
-   Set title bar methods for user provided titlebar.

## Version 0.1.1

-   Edited resizing functionality
-   Removed custom cursor methods
-   Set title bar methods for user provided titlebar.

---------------------------

## Version 0.1.0

-   Added Examples
-   Added Unittests
-   Minimizing margins and default style settings

----------------------------

## Version 0.0.1

-   Initial Version
